Basic runner for running a Sierra program on the vm.
Re-exports
pub use casm_run::CairoHintProcessor;pub use casm_run::StarknetState;
Modules
Macros
- insert_
value_ to_ cellref - Inserts a value into the vm memory cell represented by the cellref.
Structs
- Profiling
Info Collection Config - Configuration for the profiling info collection phase.
- RunResult
- The full result of a run.
- RunResult
Starknet - The full result of a run with Starknet state.
- Sierra
Casm Runner - Runner enabling running a Sierra program on the vm.
- Starknet
Execution Resources - The execution resources in a run. Extends ExecutionResources by including the used syscalls for starknet.
Enums
- Arg
- An argument to a sierra function run,
- RunResult
Value - The ran function return value.
- Runner
Error
Functions
- build_
hints_ dict - Builds hints_dict required in cairo_vm::types::program::Program from instructions.
- initialize_
vm - Initializes a vm by adding a new segment with builtins cost and a necessary pointer at the end of the program, as well as placing the arguments at the initial ap values.
- token_
gas_ cost